Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mumble-voip/mumble.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDavide Beatrici <git@davidebeatrici.dev>2020-07-17 20:12:40 +0300
committerDavide Beatrici <git@davidebeatrici.dev>2020-07-17 20:12:40 +0300
commit920bc7528eb76bf6c1d3d39d1a393c01740f868f (patch)
treec68c5850e0fed38aca4308ef9fc61f84303be1b0 /scripts
parent6a7251951b11389ce1ae6859f4dae1fb9ce6f795 (diff)
CI(azure-pipelines): use correct path for build output
"Agent.BuildDirectory" refers to the path on the agent where all folders for the pipeline are created. "Build.BinariesDirectory" is the correct variable to use: it refers to the path that can be used as an output folder for compiled binaries. Reference: https://docs.microsoft.com/en-us/azure/devops/pipelines/build/variables
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/azure-pipelines/build_linux.bash10
-rwxr-xr-xscripts/azure-pipelines/build_macos.bash10
-rw-r--r--scripts/azure-pipelines/build_windows.bat6
3 files changed, 13 insertions, 13 deletions
diff --git a/scripts/azure-pipelines/build_windows.bat b/scripts/azure-pipelines/build_windows.bat
index e8a60a07d..d9e2eb03a 100644
--- a/scripts/azure-pipelines/build_windows.bat
+++ b/scripts/azure-pipelines/build_windows.bat
@@ -12,8 +12,8 @@
::
:: Predefined variables:
::
-:: AGENT_BUILDDIRECTORY - The local path on the agent where all folders
-:: for a given build pipeline are created
+:: BUILD_BINARIESDIRECTORY - The local path on the agent that can be used
+:: as an output folder for compiled binaries.
:: BUILD_SOURCESDIRECTORY - The local path on the agent where the
:: repository is downloaded.
:: AGENT_TOOLSDIRECTORY - The directory used by tasks such as
@@ -35,7 +35,7 @@
for /f "tokens=* USEBACKQ" %%g in (`python "scripts/mumble-version.py"`) do (SET "VER=%%g")
-cd /d %AGENT_BUILDDIRECTORY%
+cd /d %BUILD_BINARIESDIRECTORY%
call "C:\Program Files (x86)\Microsoft Visual Studio\2019\Enterprise\VC\Auxiliary\Build\vcvars64.bat"
diff --git a/scripts/azure-pipelines/build_linux.bash b/scripts/azure-pipelines/build_linux.bash
index de75b644f..dc0e72bac 100755
--- a/scripts/azure-pipelines/build_linux.bash
+++ b/scripts/azure-pipelines/build_linux.bash
@@ -7,15 +7,15 @@
#
# Below is a list of configuration variables used from environment.
#
# AGENT_BUILDDIRECTORY - The local path on the agent where all folders
# for a given build pipeline are created
# BUILD_SOURCESDIRECTORY - The local path on the agent where the
# repository is downloaded.
#
VER=$(python scripts/mumble-version.py)
-cd $AGENT_BUILDDIRECTORY
+cd $BUILD_BINARIESDIRECTORY
# QSslDiffieHellmanParameters was introduced in Qt 5.8, Ubuntu 16.04 has 5.5.
cmake -G Ninja -DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX=appdir/usr -DBUILD_TESTING=ON -Dversion=$VER -Dsymbols=ON -Dqssldiffiehellmanparameters=OFF $BUILD_SOURCESDIRECTORY
@@ -7,15 +7,15 @@
# Below is a list of configuration variables used from environment.
#
-# AGENT_BUILDDIRECTORY - The local path on the agent where all folders
-# for a given build pipeline are created
-# BUILD_SOURCESDIRECTORY - The local path on the agent where the
-# repository is downloaded.
+# BUILD_BINARIESDIRECTORY - The local path on the agent that can be used
+# as an output folder for compiled binaries.
+# BUILD_SOURCESDIRECTORY - The local path on the agent where the
+# repository is downloaded.
#
VER=$(python scripts/mumble-version.py)
diff --git a/scripts/azure-pipelines/build_macos.bash b/scripts/azure-pipelines/build_macos.bash
index 3ad81b379..f05256837 100755
--- a/scripts/azure-pipelines/build_macos.bash
+++ b/scripts/azure-pipelines/build_macos.bash
@@ -7,15 +7,15 @@
#
# Below is a list of configuration variables used from environment.
#
# AGENT_BUILDDIRECTORY - The local path on the agent where all folders
# for a given build pipeline are created
# BUILD_SOURCESDIRECTORY - The local path on the agent where the
# repository is downloaded.
#
VER=$(python scripts/mumble-version.py)
-cd $AGENT_BUILDDIRECTORY
+cd $BUILD_BINARIESDIRECTORY
cmake -G Ninja -DCMAKE_TOOLCHAIN_FILE=$MUMBLE_ENVIRONMENT_TOOLCHAIN -DIce_HOME="$MUMBLE_ENVIRONMENT_PATH/installed/x64-osx" -DCMAKE_BUILD_TYPE=Release -DBUILD_TESTING=ON -Dversion=$VER -Dstatic=ON -Dsymbols=ON $BUILD_SOURCESDIRECTORY
cmake --build .
@@ -7,15 +7,15 @@
# Below is a list of configuration variables used from environment.
#
-# AGENT_BUILDDIRECTORY - The local path on the agent where all folders
-# for a given build pipeline are created
-# BUILD_SOURCESDIRECTORY - The local path on the agent where the
-# repository is downloaded.
+# BUILD_BINARIESDIRECTORY - The local path on the agent that can be used
+# as an output folder for compiled binaries.
+# BUILD_SOURCESDIRECTORY - The local path on the agent where the
+# repository is downloaded.
#
VER=$(python scripts/mumble-version.py)